@@ -9,7 +9,15 @@ class Annotatable(object):
     """
 
     def __init__(self, description='UNKNOWN', **kwds):
+        """
 
+        Parameters
+        ----------
+
+        Returns
+        -------
+
+        """
         self.description = description
         # print(__name__ + str(kwds))
         super(Annotatable, self).__init__(**kwds)
@@ -17,6 +25,13 @@ class Annotatable(object):
     @property
     def description(self):
         """ xx must be a property for ``self.xx = yy`` to work in super class after xx is set as a property also by a subclass.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+
         """
         try:
             return self._description
@@ -25,12 +40,43 @@ class Annotatable(object):
 
     @description.setter
     def description(self, description):
+        """ Property of the description of this Annotatable object.
+
+        Parameters
+        ----------
+        description : string
+                         The new descripition.
+
+        Returns
+        -------
+
+        """
+
         self._description = description
 
     def getDescription(self):
-        """ gets the description of this Annotatable object. """
-        return self.description  # __getattribute__('description')
+        """ gets the description of this Annotatable object.
+
+        Parameters
+        ----------
+
+        Returns
+        -------
+        string:
+              The current description.
+        """
+        return self.description
 
     def setDescription(self, newDescription):
-        """ sets the description of this Annotatable object. """
-        self.description = newDescription  # __setattr__('description', newDescription)
+        """ sets the description of this Annotatable object.
+
+        Parameters
+        ----------
+        newDescription : string
+                         The new descripition.
+
+        Returns
+        -------
+
+        """
+        self.description = newDescription
