@@ -6,5 +6,11 @@ class Copyable(object):
     """ Interface for objects that can make a copy of themselves. """
 
     def copy(self):
-        """ Makes a deep copy of itself. """
+        """ Makes a deep copy of itself.
+        Parameters
+        ----------
+
+        Returns
+        -------
+        """
         return deepcopy(self)
