@@ -8,6 +8,7 @@ from .dataset import CompositeDataset
 from .tabledataset import TableDataset
 from .arraydataset import ArrayDataset, Column
 from ..pal.context import Context, MapContext
+from ..utils.loadfiles import loadMedia
 from .finetime import FineTime
 
 import copy
@@ -67,8 +68,25 @@ def get_sample_product():
     """
     A complex product as a reference for testing and demo.
 
+    ```
+    prodx --+-- meta --+-- speed
+            |
+            +-- Temperature -+-- data=[768, ...] , unit=C
+            |                |
+            |                +-- meta --+-- T0
+            |
+            +-- results --+-- calibration -- data=[[109..]], unit=count
+                          |
+                          +-- Time_Energy_Pos --+-- Time   : data=[...]
+                          |                     +-- Energy : data=[...]
+                          |                     +-- y      : data=[...]
+                          |                     +-- z      : data=[...]
+                          |
+                          +-- Image -- data = b'\87PNG', content='Content-type: image/png'
+    ```
+
     """
-    prodx = Product('A complex product')
+    prodx = Product('A complex product for demonstration.')
     prodx.creator = 'Frankenstein'
     # add a parameter with validity descriptors to the product
     prodx.meta['speed'] = NumericParameter(
@@ -117,10 +135,10 @@ def get_sample_product():
 
     # an image
     fname = 'imageBlue.png'
-    with open(op.abspath(op.dirname(__file__))+'/resources/'+fname, 'rb') as f:
-        image = ArrayDataset(data=f.read(), description='An image in an array')
+    fname = op.join(op.join(op.abspath(op.dirname(__file__)),
+                            'resources'), fname)
+    image = loadMedia(fname)
     image.file = fname
-    image.content = 'Content-type: image/png'
     prodx['Image'] = image
 
     return prodx
