@@ -2,17 +2,20 @@
 
 
 from fdi.dataset.product import Product
+from fdi.dataset.numericparameter import NumericParameter
+from fdi.dataset.stringparameter import StringParameter
 from fdi.dataset.eq import deepcmp
 from fdi.dataset.testproducts import get_sample_product
 from fdi.pal.productstorage import ProductStorage
 from fdi.pal.query import MetaQuery
 from fdi.pal.poolmanager import PoolManager, DEFAULT_MEM_POOL
-from fdi.pal.httpclientpool import HttpClientPool
+from fdi.pal.httpclientpool import HttpClientPool, serialize_args, parseApiArgs
 from fdi.pns.fdi_requests import *
 from fdi.utils.getconfig import getConfig
 from fdi.utils.common import fullname
 
 import pytest
+import urllib
 import sys
 
 
@@ -45,6 +48,34 @@ def init_test():
     pass
 
 
+def test_serialize_args():
+    a = [1, -2, 'a', 'b c', True, None, NumericParameter(42)]
+    k = {'a': 'r', 'f': 0, 'b': True, 'k': None, 's': StringParameter('4..2')}
+    s = serialize_args(*a, **k)
+    # print(s)
+    s0 = urllib.parse.unquote(s)
+    code, a1, k1 = parseApiArgs(s0.split('/'))
+    assert code == 200
+    assert a == a1
+    assert k == k1
+    a = [1]
+    k = {}
+    s = serialize_args(*a, **k)
+    s0 = urllib.parse.unquote(s)
+    code, a1, k1 = parseApiArgs(s0.split('/'))
+    assert code == 200
+    assert a == a1
+    assert k == k1
+    a = []
+    k = {'s': 2}
+    s = serialize_args(*a, **k)
+    s0 = urllib.parse.unquote(s)
+    code, a1, k1 = parseApiArgs(s0.split('/'))
+    assert code == 200
+    assert a == a1
+    assert k == k1
+
+
 def test_gen_url(server):
     """ Makesure that request create corrent url
     """
@@ -57,7 +88,7 @@ def test_gen_url(server):
     logger.info('Test GET HK')
     got_hk_url = urn2fdiurl(
         urn=sampleurn, poolurl=samplepoolurl, contents='housekeeping', method='GET')
-    hk_url = aburl + '/' + samplepoolname + '/hk'
+    hk_url = aburl + '/' + samplepoolname + '/hk/'
     assert got_hk_url == hk_url, 'Housekeeping url error: ' + got_hk_url + ':' + hk_url
 
     logger.info('Test GET classes, urns, tags, webapi url')
@@ -92,21 +123,21 @@ def test_gen_url(server):
     logger.info('Post product url')
     got_post_product_url = urn2fdiurl(
         urn=sampleurn, poolurl=samplepoolurl, contents='product', method='POST')
-    post_product_url = aburl + '/'+samplepoolname + '/fdi.dataset.product.Product/10'
+    post_product_url = aburl + '/' + samplepoolname+'/'
     assert got_post_product_url == post_product_url, 'Post product url error: ' + \
         got_post_product_url
 
     logger.info('Delete product url')
     got_del_product_url = urn2fdiurl(
         urn=sampleurn, poolurl=samplepoolurl, contents='product', method='DELETE')
-    del_product_url = aburl + '/' + samplepoolname + '/fdi.dataset.product.Product/10'
+    del_product_url = aburl + '/urn' + sampleurn
     assert got_del_product_url == del_product_url, 'Delete product url error: ' + \
         got_del_product_url
 
     logger.info('Delete pool url')
     got_del_pool_url = urn2fdiurl(
-        urn=sampleurn, poolurl=samplepoolurl, contents='pool', method='DELETE')
-    del_pool_url = aburl + '/' + samplepoolname
+        urn=sampleurn, poolurl=samplepoolurl, contents='wipe_pool', method='DELETE')
+    del_pool_url = aburl + '/' + samplepoolname + '/wipe'
     assert got_del_pool_url == del_pool_url, 'Delete product url error: ' + got_del_pool_url
 
     logger.info('Test corrupt request url')
