@@ -11,6 +11,7 @@ from fdi.dataset.deserialize import deserialize
 from fdi.dataset.product import Product
 from fdi.pal.poolmanager import PoolManager
 from fdi.pal.productstorage import ProductStorage
+from fdi.pal.productpool import Lock_Path_Base
 from fdi.utils.common import lls, trbk, fullname
 from fdi.utils.fetch import fetch
 from fdi.httppool.route import httppool_server
@@ -95,7 +96,7 @@ if 0:
 
 @pytest.fixture(scope="module")
 def project_app(pc):
-    from httppool_app import create_app
+    from fdi.httppool import create_app
     return create_app(config_object=pc, logger=logger)
 
 
@@ -153,10 +154,10 @@ def check_response(o, failed_case=False, excluded=None):
         excluded = []
     assert o is not None, "Server is having trouble"
     someone = any(x in o for x in excluded)
+    assert 'result' in o or \
+        'Bad string to decode as JSON' not in o \
+        or someone, o
     if not failed_case:
-        assert 'result' in o or \
-            'Bad string to decode as JSON' not in o \
-            or someone, o
         if not someone:
             # properly formated
             if failed_case is not None:
@@ -216,8 +217,8 @@ def test_wipe_all_pools_on_server(server, local_pools_dir, client, userpass):
     assert len(get_files_in_local_dir('', local_pools_dir)) >= n+1
 
     # wipe all pools
-    url = aburl + '/' + 'wipe_all_pools'
-    x = client.put(url, auth=auth)
+    url = aburl + '/' + 'pools/wipe_all'
+    x = client.delete(url, auth=auth)
     o = getPayload(x)
     check_response(o, failed_case=False)
 
@@ -350,9 +351,9 @@ def populate_pool(poolid, aburl, auth, clnt):
                     instrument=random.choice(instruments))
         x.creator = i
         data = serialize(x)
-        url = aburl + '/' + poolid + '/' + prodt + '/' + str(index)
+        url = aburl + '/' + poolid + '/'
         x = clnt.post(url, auth=HTTPBasicAuth(*auth), data=data)
-        print(len(data))
+        # print(len(data))
         o = getPayload(x)
         check_response(o)
         urns.append(o['result'])
@@ -392,8 +393,7 @@ def test_CRUD_product(local_pools_dir, server, userpass, client):
     logger.info('read product')
 
     u = random.choice(urns)
-    # remove the leading 'urn:'
-    url = aburl + '/' + u[4:].replace(':', '/')
+    url = aburl + '/' + u  # [4:].replace(':', '/')
     x = client.get(url, auth=auth)
     o = getPayload(x)
     check_response(o)
@@ -435,7 +435,7 @@ def test_CRUD_product(local_pools_dir, server, userpass, client):
 
     logger.info('check count')
     num = len(o['result'][prodt]['sn'])
-    apipath = '/api/getCount/' + prodt + ':str'
+    apipath = '/api/getCount/' + prodt
     url = aburl + '/' + post_poolid + apipath
     x = client.get(url, auth=auth)
     o = getPayload(x)
@@ -467,7 +467,7 @@ def test_CRUD_product(local_pools_dir, server, userpass, client):
     origin_prod = len(files)
 
     index = files[-1].rsplit('_', 1)[1]
-    url = aburl + '/' + post_poolid + '/fdi.dataset.product.Product/' + index
+    url = aburl + '/urn' + post_poolid + '/fdi.dataset.product.Product/' + index
 
     x = client.delete(url, auth=auth)
 
@@ -509,7 +509,7 @@ def test_CRUD_product(local_pools_dir, server, userpass, client):
     url = aburl + '/' + post_poolid
     x = client.delete(url, auth=auth)
     o = getPayload(x)
-    check_response(o, failed_case=True)
+    check_response(o)
 
     # this should fail as pool is unregistered on the server
     url = aburl + '/' + post_poolid + '/api/isEmpty'
@@ -532,13 +532,19 @@ def test_product_path(server, userpass, client):
     prodt = fullname(p)
     data = serialize(p)
     # print(len(data))
-    url1 = url0+prodt + '/0'
+    url1 = url0
     x = client.post(url1, auth=auth, data=data)
     o = getPayload(x)
     check_response(o)
     urn = o['result']
 
     # API
+    # url0       = 'http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/'
+    # url1       = 'http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/'
+    # urn        = 'urn:fdi_serv.test_httppool:fdi.dataset.product.Product:0'
+    # pcls       = 'fdi.dataset.product.Product'
+    # urlapi     = 'http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/fdi.dataset.product.Product'
+
     pcls = urn.split(':')[2].replace(':', '/')
     urlapi = url0 + pcls
     # 'http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/fdi.dataset.product.Product'
@@ -552,9 +558,9 @@ def test_product_path(server, userpass, client):
     # test product paths
     segs = ["results", "Time_Energy_Pos", "Energy", "data"]
     pth = '/'.join(segs)
-    # make url w/  urn1
-    #
-    url2 = url0 + urn.replace(':', '+') + '/' + pth
+    # make url w/  urn
+    #url2       = 'http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/fdi.dataset.product.Product/0/results/Time_Energy_Pos/Energy/data'
+    url2 = aburl + urn.replace(':', '/')[3:] + '/' + pth
     x = client.get(url2, auth=auth)
     o = getPayload(x)
     check_response(o)
@@ -626,7 +632,7 @@ async def lock_pool(poolid, sec, local_pools_dir):
     logger.info('Keeping files locked for %f sec' % sec)
     ppath = os.path.join(local_pools_dir, poolid)
     # lock to prevent writing
-    lock = '/tmp/fdi_locks/' + ppath.replace('/', '_') + '.write'
+    lock = Lock_Path_Base + ppath.replace('/', '_') + '.write'
     logger.debug(lock)
     with filelock.FileLock(lock):
         await asyncio.sleep(sec)
